# tistory

[![PyPI Latest Release](https://img.shields.io/pypi/v/tistory.svg)](https://pypi.org/project/tistory/)
![](https://img.shields.io/badge/python-3.8-blue.svg)
![](https://img.shields.io/badge/requests-2.28.1-red.svg)
![](https://img.shields.io/badge/selenium-4.4.0-yellow.svg)
![](https://img.shields.io/badge/api-tistory-green.svg)


## 기여자

<div align="center">
    <table>
    <tr>
        <td align="center">
            <a href="https://github.com/wooiljeong">
            <img src="https://avatars.githubusercontent.com/u/38076110?v=4" width="100px;" alt=""/><br />
            <sub><b>정우일</b></sub></a><br />
        </td>
    </tr>
    </table>
</div>


## 소개

tistory는 티스토리 블로그 오픈 API를 파이썬으로 쉽게 이용할 수 있도록 돕는 오픈소스 라이브러리입니다. 


## 설치

```bash
pip install tistory
```


## 사용 설명서

- [Python tistory 패키지로 블로그 자동화하기](https://wooiljeong.github.io/python/tistory)


## 참조

- [티스토리 오픈 API 신청](https://www.tistory.com/guide/api/manage/register)
- [티스토리 오픈 API 가이드](https://tistory.github.io/document-tistory-apis/)


<div align=center>

[![Hits](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fwooiljeong%2Ftistory&count_bg=%23FF6666&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false)](https://hits.seeyoufarm.com)

</div>